@@ -16,7 +16,7 @@ use constant FFR     => 'File::Find::Rule';
 
 use vars qw{$VERSION};
 BEGIN {
-        $VERSION = '0.24';
+        $VERSION = '0.25';
 }
 
 # Does exec work on this platform
@@ -190,6 +190,12 @@ sub main {
                 $script = 't';
         }
 
+	# Abuse the highly mature logic in Cwd to define an $ENV{PWD} value
+	# by chdir'ing to the current directory.
+	# This lets us get the current directory without losing symlinks.
+	Cwd::chdir(curdir());
+	my $orig = $ENV{PWD} or die "Failed to get original directory";
+
         # Can we locate the distribution root directory
         if ( in_subdir ) {
                 Cwd::chdir(updir());
@@ -205,7 +211,21 @@ sub main {
 	}
 
 	# Locate the test script to run
-        unless ( $script =~ /\.t$/ ) {
+	if ( $script =~ /\.t$/ ) {
+		# EITHER
+		# 1. They tab-completed the script relative to the original directory (most likely)
+		# OR
+		# 2. They typed the entire name of the test script
+		my $tab_completed = File::Spec->catfile( $orig, $script );
+		if ( -f $tab_completed ) {
+			if ( $orig eq $ENV{PWD} ) {
+				$script = $script; # Included for clarity
+			} else {
+				$script = File::Spec->abs2rel( $tab_completed, $ENV{PWD} );
+			}
+		}
+
+        } else {
                 # Get the list of possible tests
                 my @possible = FFR->file->name('*.t')->in( 't' );
 
@@ -231,7 +251,10 @@ sub main {
         }
 
         # Rerun make if needed
-        if ( in_distroot and has_makefile ) {
+	# Do NOT run make if there is no Makefile.PL, because it likely means
+	# there is a hand-written Makefile and NOT one derived from Makefile.PL,
+	# and we have no idea what functionality we might trigger.
+        if ( in_distroot and has_makefile and has_makefilepl ) {
                 run( make );
         }
 
@@ -243,13 +266,6 @@ sub main {
                 push @flags, '-Ilib';
         }
 
-	# On some platforms (mostly Windows), we get errors because
-	# of Term::Cap issues. To avoid this, set TERM=dumb if the
-	# user does not have a TERM value already.
-	# This doesn't remove all possible errors, just the most
-	# annoying and common ones.
-	$ENV{TERM} ||= 'dumb';
-
         # Hand off to the perl debugger
         unless ( pler->is_verbose ) {
                 message( "# Debugging $script...\n" );
